@@ -1,9 +1,11 @@
+import os
+from pathlib import Path
+
 import psycopg2
 from psycopg2.extras import RealDictCursor
 from sqlalchemy import create_engine
-import os
-from pathlib import Path
-from cj2pgsql.resources import object_types
+
+from cjdb.resources import object_types
 
 
 def get_db_engine(args, echo=False):
